@@ -15,7 +15,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include <gtk/gtk.h>
@@ -55,6 +54,9 @@ void window_cmd_file_open	(GtkAction *action,
 void window_cmd_file_save_as    (GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_file_save_as_application (GtkAction *action,
+                                          EphyWindow *window);
+
 void window_cmd_file_print_setup (GtkAction *action,
 				  EphyWindow *window);
 
